@@ -7,7 +7,7 @@ def test_syntax_errors():
     DIR_PATH, this_filename = os.path.split(__file__)
     DATA_PATH = os.path.join(DIR_PATH, "syntax_errors.yaml")
 
-    txt = open(DATA_PATH, "rt").read()
+    txt = open(DATA_PATH, "rt", encoding="utf-8").read()
     data = yaml.compose(txt)
 
     try:
@@ -35,6 +35,9 @@ def test_syntax_errors():
         assert e.column == 26
 
 
+test_syntax_errors()
+
+
 def test_variable_definitions_errors():
 
     from dolang.grammar import parse_string
@@ -45,7 +48,7 @@ def test_variable_definitions_errors():
     DIR_PATH, this_filename = os.path.split(__file__)
     DATA_PATH = os.path.join(DIR_PATH, "syntax_errors.yaml")
 
-    txt = open(DATA_PATH, "rt").read()
+    txt = open(DATA_PATH, "rt", encoding="utf-8").read()
     data = yaml.compose(txt)
 
     for v in (data["definitions"]).value:
